### Arches 4.5.0 release notes

The Arches team has been busy improving Arches and fixing several bugs as well.
Below you'll find a listing of more changes included in the latest release.

Some of the highlights:

- Upgraded Arches to use the latest version (6.6.2) of Elasticsearch

#### Upgrading Arches

Users are encouraged to update at their earliest convenience.  Completely re-installing Arches is the easiest way to accomplish this.

If you can't completely re-install Arches (because you have data in the system that you want to preserve) then you'll need to upgrade by running the following commands in your activated virtual environment:

    pip install arches --upgrade --no-binary :all:
    
#### Update Arches to use the latest Elasticsearch

    python manage.py es install

This will put the latest version of Elasticsearch into the directory from which you ran the previous command.  At this point you can move the elasticsearch-6.6.2 directory to a new location if you desire.

Now do the following:

- Stop the currently running Elasticsearch instance.
- Copy the `data` directory from your old Elasticsearch instance to the new instance
- Start the new instance of Elasticsearch

Now you can run the following commands

    python manage.py migrate

After you are satisifed that Elasticsearch has been upgraded properly you may remove the old elasticsearch-5.2.1 directory and remove the following indexes which have been superceeded:
    
- {my_proj_name}_strings
- {my_proj_name}_resource
- {my_proj_name}_resource_relations_temp


If you have Arches running on a web server such as Apache, be sure to update your static files directory and restart your web server.

As always the documentation can be found at <http://arches.readthedocs.io>

#### Upgrading an Arches project

1.  Update the knockout.js package from 3.4 to 3.5 in your project by editing the line in your package.json:

        "knockout": "3.5.0",

        and run: `yarn install`


#### Additional steps for developers:

<!-- If you are running arches from a git repo, be aware that you will need to update your Python dependencies by running (with your virtualenv activated):


    pip install -r arches/install/requirements.txt
    pip install -r arches/install/requirements_dev.txt

 -->
### Additional Changes


# Testing Script

Before Version Release, go through this checklist to confirm that Arches is running as intended.

## Index

| Test Subject   |      Chrome     |      Safari     |     Firefox     |       IE11      | UI                        | Notes                                |
| -------------- | :-------------: | :-------------: | :-------------: | :-------------: | ------------------------- | ------------------------------------ |
| (Test Subject) | (use indicator from list below) | (use indicator from list below) | (use indicator from list below) | (use indicator from list below) | :white_check_mark: (to confirm that the UI has rendered correctly) or :x: (to confirm that the UI failed to render correctly) | (add ticket #, details on bug, etc.) |

When doing a test pass, consider using these status indicators:  
:white_check_mark: = Tested & Approved  
:x: = Merge blocking  
:construction: = Non-blocking bugs  
:ok: = Issue has been fixed  
:question: = Open question  

* * *

## Install

Assigned to: Alexei

| Test Subject                                                   | Chrome | Safari | Firefox | IE11 | UI  | Notes |
| -------------------------------------------------------------- | :----: | :----: | :-----: | :--: | --- | ----- |
| Confirm that upgrading from the previous release is issue free |   ?   |   ?   |   ?   |   ?   | ?   | -     |

* * *

## Authentication

Assigned to: Ryan

Ensure that all browsers are compatible with Authentication process.

| Test Subject                                                             | Chrome | Safari | Firefox | IE11 | UI  | Notes |
| ------------------------------------------------------------------------ | :----: | :----: | :-----: | :--: | --- | ----- |
| User can sign themselves up for a new Arches account                     |   ?        |    ?   |    ?    |   ?  | ?   | -     |
| User is added to default group (Crowdsource Editor)                      |   ?          |    ?   |    ?    |   ?  | ?   | -     |
| User can log in with their email address                                 |   ?          |    ?   |    ?    |   ?  | ?   | -     |
| User can reset their password                                            |   ?          |    ?   |    ?    |   ?  | ?   | -     |
| User can edit their profile (First and Last name, email address, etc...) |   ?          |    ?   |    ?    |   ?  | ?   | -     |

* * *

## System Settings

Assigned to: Cyrus

#### Basic Settings

| Test Subject                                                                                                                 | Chrome | Safari | Firefox | IE11 | UI  | Notes |
| ---------------------------------------------------------------------------------------------------------------------------- | :----: | :----: | :-----: | :--: | --- | ----- |
| Project Name - Updating name updates in index.htm and the page tab                                                           |   ?   |    ?   |    ?    |   ?  | ?   | -     |
| Web Analytics - String value inserts in base.htm at the location of this template variable:{{GOOGLE_ANALYTICS_TRACKING_ID}} |   ?   |    ?   |    ?    |   ?  | ?   | -     |

#### Map Settings

Assigned to: Galen (extent verified by @chiatt)

| Test Subject                                                                                                                                                                                    | Chrome | Safari | Firefox | IE11 | UI  | Notes |
| ----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- | :----: | :----: | :-----: | :--: | --- | ----- |
| API Key - Key saves and API calls are successful                                                                                                                                                |   ?   |   ?   |    ?    |   ?  | ?   | -     |
| Hex Grid Precision - Saves properly, but errors if precision is too high (\`Exception detail: TransportError(400, u'parsing_exception', u'[geohash_grid] failed to parse field [precision]')``) |   ?   |   ?   |    ?    |   ?  | ?   | -     |
| Hex Cell Size - Changes reflected in Search results                                                                                                                                             |   ?   |   ?   |    ?    |   ?  | ?   | -     |
| Default Zoom - Changes reflected in Card Config Manager                                                                                                                                         |   ?   |   ?   |    ?    |   ?  | ?   | -     |
| Min Zoom - Changes reflected in Card Config Manager                                                                                                                                             |   ?   |   ?   |    ?    |   ?  | ?   | -     |
| Max Zoom - Changes reflected in Card Config Manager                                                                                                                                             |   ?   |   ?   |    ?    |   ?  | ?   | -     |
| Project Extent - Changes reflected in Card Config Manager                                                                                                                                       |   ?   |   ?   |    ?    |   ?  | ?   | -     |

#### Search Settings

Assigned to: Galen

Basic Search Settings

| Test Subject                                                   | Chrome | Safari | Firefox | IE11 | UI  | Notes |
| -------------------------------------------------------------- | :----: | :----: | :-----: | :--: | --- | ----- |
| Searches per page updates properly in Search                   |   ?   |   ?   |    ?    |   ?  | ?   | -     |
| Number of search suggestions is reflected in search term input |   ?   |   ?   |    ?    |   ?  | ?   | -     |

Temporal Search Settings (not in use)

| Test Subject                                                                                       | Chrome | Safari | Firefox | IE11 | UI  | Notes |
| -------------------------------------------------------------------------------------------------- | :----: | :----: | :-----: | :--: | --- | ----- |
| Changes in time wheel color ramp are reflected in time wheel change time wheel colors (not in use) |    -   |    -   |    -    |   -  | -   | -     |
| Changes in time wheel config are reflected in time wheel (not in use)                              |    -   |    -   |    -    |   -  | -   | -     |

Saved Searches

| Test Subject                                                                                                       | Chrome | Safari | Firefox | IE11 | UI  | Notes |
| ------------------------------------------------------------------------------------------------------------------ | :----: | :----: | :-----: | :--: | --- | ----- |
| A new search saves with a name, search url, description, and image and displays properly in the saved search page. |   ?   |   ?   |    ?    |   ?  | ?   | -     |
| Users can delete a saved search                                                                                    |   ?   |   ?   |    ?    |   ?  | ?   | -     |

* * *

## Map Widget

Assigned to: Namjun

Test in the Card Configuration Manager.

| Test Subject                                                                                                                                            | Chrome | Safari | Firefox | IE11 | UI  | Notes |
| ------------------------------------------------------------------------------------------------------------------------------------------------------- | :----: | :----: | :-----: | :--: | --- | ----- |
| Point line and poly geoms can be created, edited, and deleted                                                                                           |   ?   |    ?   |    ?    |   ?  | ?   | -     |
| XY widget is working properly                                                                                                                           |   ?   |    ?   |    ?    |   ?  | ?   | -     |
| Valid geojson entered in the geojson input adds features to the map and pans to those features. If geojson is invalid user has a chance to update data. |   ?   |    ?   |    ?    |   ?  | ?   | -     |

* * *

## Map Layer Manager

Assigned to: Rob

#### Resource Layers

Assigned to: Rob

| Test Subject                                                                                                                         | Chrome | Safari | Firefox | IE11 | UI  | Notes |
| ------------------------------------------------------------------------------------------------------------------------------------ | :----: | :----: | :-----: | :--: | --- | ----- |
| Settings - changes to the name and icon of a layer are reflected in the map widget overlay list and overlay library                  |   ?   |    ?   |    ?    |   ?  | ?   | -     |
| Deactivating/Activating a resource layer hides/shows the layer in the map widget overlay list and overlay library                    |   ?   |    ?   |    ?    |   ?  | ?   | -     |
| Style Settings - changes to the layer style are displayed in the layer                                                               |   ?   |    ?   |    ?    |   ?  | ?   | -     |
| Style Settings Advanced - changes to the layer style are displayed in the layer                                                      |   ?   |    ?   |    ?    |   ?  | ?   | -     |
| Activating caching adds a cache folder for a resource in your projects tile server directory                                          |   ?   |    ?   |    ?    |   ?  | ?   | -     |
| Activating clean cache on edit updates the cache when a geometry is edited                                                           |   ?   |    ?   |    ?    |   ?  | ?   | -     |
| Setting permissions for a user or group as No Access removes the user and group from the permissions list under the permissions tab. |   ?   |    ?   |    ?    |   ?  | ?   | -     |

#### Clustering (Resource Layers)

Assigned to: Rob

| Test Subject                                                                               | Chrome | Safari | Firefox | IE11 | UI  | Notes |
| ------------------------------------------------------------------------------------------ | :----: | :----: | :-----: | :--: | --- | ----- |
| Increasing cluster distance causes features to cluster at increased distances between them |   ?   |    ?   |    ?    |   ?  | ?   | -     |
| Increasing cluster max zoom causes clusters to be formed at higher zoom levels             |   ?   |    ?   |    ?    |   ?  | ?   | -     |
| Decreasing min points to 2 points causes clusters to form with only 2 points               |   ?   |    ?   |    ?    |   ?  | ?   | -     |
| Increasing vector simplification to 0.0 prevents simplification a low zoom levels          |   ?   |    ?   |    ?    |   ?  | ?   | -     |

#### Basemaps

Assigned to: Rob

| Test Subject                                                                                    | Chrome | Safari | Firefox | IE11 | UI  | Notes |
| ----------------------------------------------------------------------------------------------- | :----: | :----: | :-----: | :--: | --- | ----- |
| Changing the default search basemap in the basemap settings is reflected on the search page     |   ?   |    ?   |    ?    |   ?  | ?   | -     |
| Settings - changes to the name and icon of a layer are reflected in the map widget basemap list |   ?   |    ?   |    ?    |   ?  | ?   | -     |
| User can delete a basemap and it no longer appears in the map widget's list of basemaps         |   ?   |    ?   |    ?    |   ?  | ?   | -     |

#### Overlays

Assigned to: Rob

| Test Subject                                                                                                        | Chrome | Safari | Firefox | IE11 | UI  | Notes |
| ------------------------------------------------------------------------------------------------------------------- | :----: | :----: | :-----: | :--: | --- | ----- |
| Settings - changes to the name and icon of a layer are reflected in the map widget overlay list and overlay library |   ?   |    ?   |    ?    |   ?  | ?   | -     |
| User can delete an overlay and it no longer appears in the map widget overlay library                               |   ?   |    ?   |    ?    |   ?  | ?   | -     |

* * *

## Import/Export

Assigned to: Cyrus

| Test Subject               | Chrome | Safari | Firefox | IE11 | UI  | Notes |
| -------------------------- | :----: | :----: | :-----: | :--: | --- | ----- |
| Create_mapping_file        |   ?   |    ?   |    ?    |   ?  | ?   | -     |
| Import business data (cli) |   ?   |    ?   |    ?    |   ?  | ?   | -    |
| Export business data (cli) |   ?   |    ?   |    ?    |   ?  | ?   | -     |
| Load package (cli)         |   ?   |    ?   |    ?    |   ?  | ?   | -     |
| Create package (cli)       |   ?   |    ?   |    ?    |   ?  | ?   | -     |

* * *

## Resource Instance Management

Assigned to: Namjun

#### Data Types

Confirm that the user is able to edit the following data types. Use the Test model to quickly test all ten data types.
Note (GeoJson is covered by map widget testing in a different section)

| Test Subject           | Chrome | Safari | Firefox | IE11 | UI  | Notes |
| ---------------------- | :----: | :----: | :-----: | :--: | --- | ----- |
| String                 |   ?   |    ?   |    ?    |   ?  | ?   | -     |
| Concepts               |   ?   |    ?   |    ?    |   ?  | ?   | -     |
| Domains                |   ?   |    ?   |    ?    |   ?  | ?   | -     |
| Images                 |   ?   |    ?   |    ?    |   ?  | ?   | -     |
| Dates                  |   ?   |    ?   |    ?    |   ?  | ?   | -     |
| Number                 |   ?   |    ?   |    ?    |   ?  | ?   | -     |
| Boolean                |   ?   |    ?   |    ?    |   ?  | ?   | -     |
| Resource instance type |   ?   |    ?   |    ?    |   ?  | ?   | -     |
| Node data type         |   ?   |    ?   |    ?    |   ?  | ?   | -     |

#### Resource Descriptors

Assigned to: Alexei

Updating a resource descriptor should be reflected in the following subjects.

| Test Subject                                                                                        | Chrome | Safari | Firefox | IE11 | UI  | Notes |
| --------------------------------------------------------------------------------------------------- | :----: | :----: | :-----: | :--: | --- | ----- |
| Search results                                                                                      |   ?   |    ?    |    ?     |   ?   | ?   | -     |
| Form headings                                                                                       |   ?   |    ?    |    ?     |   ?   | ?   | -     |
| Report headings                                                                                     |   ?   |    ?    |    ?     |   ?   | ?   | -     |
| Map popups                                                                                          |   ?   |    ?    |    ?     |   ?   | ?   | -     |
| Related resource d3 graph and listings                                                              |   ?   |    ?    |    ?     |   ?   | ?   | -     |

* * *

#### Provisional Edit Management

Assigned to: Ryan

| Test Subject                                           | Chrome | Safari | Firefox | IE11 | UI  | Notes |
| ------------------------------------------------------ | :----: | :----: | :-----: | :--: | --- | ----- |
| Provisional users see indication in a widget that their tile edits were submitted                   |   ?   |    ?   |    ?    |   ?  | ?   | -     |
| Resource reviewers are able to identify provisional tiles and can approve/discard provisional edits |   ?   |    ?   |    ?    |   ?  | ?   | -     |

* * *

## Related Resources

Assigned to: Galen

#### Resource Editor

| Test Subject                                           | Chrome | Safari | Firefox | IE11 | UI  | Notes |
| ------------------------------------------------------ | :----: | :----: | :-----: | :--: | --- | ----- |
| User can add a related resource                        |   ?   |   ?   |    ?    |   ?  | ?   | -     |
| User can delete a related resource                     |   ?   |   ?   |    ?    |   ?  | ?   | -     |
| User can change the properties of related resources    |   ?   |   ?   |    ?    |   ?  | ?   | -     |
| User can switch between table and force directed graph |   ?   |   ?   |    ?    |   ?  | ?   | -     |
| User can page through related resources in table       |   ?   |   ?   |    ?    |   ?  | ?   | -     |

#### Resource Search

| Test Subject                                                                                                                           | Chrome | Safari | Firefox | IE11 | UI  | Notes |
| -------------------------------------------------------------------------------------------------------------------------------------- | :----: | :----: | :-----: | :--: | --- | ----- |
| Hovering over a link in the force directed graph opens a panel with source and target node info and list each unique relationship type |   ?   |   ?   |    ?    |   ?  | ?   | -     |
| Hovering over a node highlights the adjacent links and the corresponding entry in the node list                                        |   ?   |   ?   |    ?    |   ?  | ?   | -     |
| Hovering over a node list entry highlights the corresponding node and its adjacent links                                               |   ?   |   ?   |    ?    |   ?  | ?   | -     |
| User can switch between table and force directed graph                                                                                 |   ?   |   ?   |    ?    |   ?  | ?   | -     |
| Entering text in the search field filters the list of list entries                                                                     |   ?   |   ?   |    ?    |   ?  | ?   | -     |
| Overlays support custom popups                                                                                                         |    ?   |    ?   |    ?    |   ?  | ?   | -     |

* * *

## Search

Assigned to: Alexei

| Test Subject                                                                                                                                                                         | Chrome | Safari | Firefox | IE11 | UI  | Notes |
| ------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------ | :----: | :----: | :-----: | :--: | --- | ----- |
| Free text search                                                                                                                                                                     |   ?   |    ?    |    ?     |   ?  |   ?   | -     |
| Concept search                                                                                                                                                                       |   ?   |    ?    |    ?     |   ?  |   ?   | -     |
| Map search                                                                                                                                                                           |   ?   |    ?    |    ?     |   ?  |   ?   | -     |
| Time range based search                                                                                                                                                              |   ?   |    ?    |    ?     |   ?  |   ?   | -     |
| Time wheel search                                                                                                                                                                    |   ?   |    ?    |    ?     |   ?  |   ?   | -     |
| Advanced search                                                                                                                                                                      |   ?   |    ?    |    ?     |   ?  |   ?   | -     |
| Related resource table search                                                                                                                                                        |:construction:|    ?   |    ?    |   ?  | ?   |Table filter is not available|
| Related resource graph search                                                                                                                                                        |   ?   |   ?    |    ?     |   ?   |   ?   | -     |
| Resource type search                                                                                                                                                                 |   ?   |    ?    |    ?     |  ?   | ?   | -     |
| Edit status search (provisional, authoritative, or both). Confirm that only resource reviewers are able to see provisional tile data                                                 |   ?   |    ?    |    ?     |   ?   | ?   | -     |
| Map should not zoom to points that a user is not permitted to read, nor should the search aggregation layer (e.g. hexbin or heatmap) indicate that a restricted resource is present. |   ?   |    ?    |    ?     |   ?   |  ?   | -     |

* * *

## Graph Design

Assigned to: Namjun

### Arches Designer

| Test Subject     | Chrome | Safari | Firefox | IE11 | UI  | Notes |
| ---------------- | :----: | :----: | :-----: | :--: | --- | ----- |
| Import graph     |   ?   |    ?   |    ?    |   ?  | ?   ||
| Export graph     |   ?   |    ?   |    ?    |   ?  | ?   | -     |
| Clone graph      |   ?   |    ?   |    ?    |   ?  | ?   | -     |
| Delete graph     |   ?   |    ?   |    ?    |   ?  | ?   | -     |
| Create branch    |   ?   |    ?   |    ?    |   ?  | ?   | -     |
| Create graph     |   ?   |    ?   |    ?    |   ?  | ?   | -     |
| Delete Instances |   ?   |    ?   |    ?    |   ?  | ?   | -     |

### Graph Designer

| Test Subject     | Chrome | Safari | Firefox | IE11 | UI  | Notes |
| ---------------- | :----: | :----: | :-----: | :--: | --- | ----- |
| Import graph     |   ?   |    ?   |    ?    |   ?  | ?   |Popup blocker will block the new windows for some of these functions.|
| Export graph     |   ?   |    ?   |    ?    |   ?  | ?   | -     |
| Clone graph      |   ?   |    ?   |    ?    |   ?  | ?   | -     |
| Delete graph     |   ?   |    ?   |    ?    |   ?  | ?   | -     |
| Create branch    |   ?   |    ?   |    ?    |   ?  | ?   | -     |
| Create graph     |   ?   |    ?   |    ?    |   ?  | ?   | -     |
| Delete Instances |   ?   |    ?   |    ?    |   ?  | ?   | -     |
| Add/Edit cards   |   ?   |    ?   |    ?    |   ?  | ?   | -     |
| Reorder widgets  in card |   ?   |    ?   |    ?    |   ?  | ?   | -     |

* * *

## Permissions Management

Assigned to: Ryan

| Test Subject                                                                                                                                            | Chrome | Safari | Firefox | IE11 | UI  | Notes |
| ------------------------------------------------------------------------------------------------------------------------------------------------------- | :----: | :----: | :-----: | :--: | --- | ----- |
| Confirm removing `read` permissions removes that section from the report                                                                                |   ?          |    ?   |    ?    |   ?  | ?   | -     |
| Confirm removing `read` permissions removes that section from the form                                                                                  |   ?          |    ?   |    ?    |   ?  | ?   | -     |
| Confirm removing `read` permissions removes that section from the adv. search                                                                           |   ?          |    ?   |    ?    |   ?  | ?   | -     |
| Confirm removing `read` permissions for a spatial nodegroup removes that resource type from map based search results                                    |   ?          |    ?   |    ?    |   ?  | ?   | -     |
| Confirm removing `read` permissions for a spatial nodegroup removes that resource type from the overlays section of the map settings                    |   ?          |    ?   |    ?    |   ?  | ?   | -     |
| Confirm removing `read` permissions for a spatial nodegroup removes the map from the Map Report                                                         |   ?          |    ?   |    ?    |   ?  | ?   | -     |
| Confirm removing `read` permissions for a date based nodegroup removes the related entries from the type dropdown in the time filter of the search page |   ?          |    ?   |    ?    |   ?  | ?   | -     |
| Confirm removing `read` permissions for a date based nodegroup reduces the wheel count appropriately                                                    |   ?          |    ?   |    ?    |   ?  | ?   | -     |
| Confirm removing `write` permissions but still having read permissions disallows saving that section of the form                                        |   ?          |    ?   |    ?    |   ?  | ?   | -     |

* * *

## Reports

Assigned to: Cyrus

#### Headers Rendering

| Test Subject                                                            | Chrome | Safari | Firefox | IE11 | UI  | Notes |
| ----------------------------------------------------------------------- | :----: | :----: | :-----: | :--: | --- | ----- |
| Confirm that report templates with map header gets rendered correctly   |   ?   |    ?   |    ?    |   ?  | ?   | -     |
| Confirm that report templates with image header gets rendered correctly |   ?   |    ?   |    ?    |   ?  | ?   | -     |
| Confirm that report templates with no header gets rendered correctly    |   ?   |    ?   |    ?    |   ?  | ?   | #4613 |

#### Data Rendering

| Test Subject           | Chrome | Safari | Firefox | IE11 | UI  | Notes |
| ---------------------- | :----: | :----: | :-----: | :--: | --- | ----- |
| String                 |   ?   |    ?   |    ?    |   ?  | ?   | -     |
| Concepts               |   ?   |    ?   |    ?    |   ?  | ?   | -     |
| Domains                |   ?   |    ?   |    ?    |   ?  | ?   | -     |
| Images                 |   ?   |    ?   |    ?    |   ?  | ?   | -     |
| Dates                  |   ?   |    ?   |    ?    |   ?  | ?   | -     |
| Number                 |   ?   |    ?   |    ?    |   ?  | ?   | -     |
| Boolean                |   ?   |    ?   |    ?    |   ?  | ?   | -     |
| Resource instance type |   ?   |    ?   |    ?    |   ?  | ?   | -     |
| Node data type         |   ?   |    ?   |    ?    |   ?  | ?   | -     |

* * *

## RDM

Assigned to: Namjun

#### Thesauri

| Test Subject       | Chrome | Safari | Firefox | IE11 | UI  | Notes |
| ------------------ | :----: | :----: | :-----: | :--: | --- | ----- |
| Add scheme         |   ?   |    ?   |    ?    |   ?  | ?   |Dialogue contents do not update right away|
| Delete scheme      |   ?   |    ?   |    ?    |   ?  | ?   | -     |
| Import scheme      |   ?   |    ?   |    ?    |   ?  | ?   |Does not import images|
| Export scheme      |   ?   |    ?   |    ?    |   ?  | ?   |Does not import images|
| Add top concept    |   ?   |    ?   |    ?    |   ?  | ?   | -     |
| Import from SPARQL |   ?   |    ?   |    ?    |   ?  | ?   |The list is not refreshed on import|
| Manage parents     |   ?   |    ?   |    ?    |   ?  | ?   |When polyhierachy is set, the selection not deactivated |
| Make collection    |   ?   |    ?   |    ?    |   ?  | ?   |If a user creates two collections with the same name they will not be able to delete either of them|
| Add label          |   ?   |    ?   |    ?    |   ?  | ?   | -     |
| Add Note           |   ?   |    ?   |    ?    |   ?  | ?   | -     |
| Add image          |   ?   |    ?   |    ?    |   ?  | ?   | -     |

#### Collections

| Test Subject                           | Chrome | Safari | Firefox | IE11 | UI  | Notes |
| -------------------------------------- | :----: | :----: | :-----: | :--: | --- | ----- |
| Add collection                         |   ?   |    ?   |    ?    |   ?  | ?   | -     |
| Delete collection                      |   ?   |    ?   |    ?    |   ?  | ?   | -     |
| Export all collections                 |   ?   |    ?   |    ?    |   ?  | ?   | -     |
| Add dropdown entry                     |   ?   |    ?   |    ?    |   ?  | ?   | -     |
| Add sort order and confirm in dropdown |   ?   |    ?   |    ?    |   ?  | ?   |In some cases custom sorting reverts to alphabetical order|

* * *
