### Arches 5.0 release notes

The Arches team has been busy improving Arches and fixing several bugs as well.
Below you'll find a listing of more changes included in the latest release.

Some of the highlights:

- Dependency Upgrades - Arches now uses:
    - Python 3.7
    - Django 2.2
    - Elasticsearch 7.4
    - Postgres 12
    - PostGIS 3
- Task Management: Arches can now be configured to delegate background tasks using Celery
- Notifications: Arches can notify users when a task is complete and developers can add custom notifications
- Search Export: Users can export search results to CSV or shapefile formats.
- Search Components: Developers can now override search components to customize the search interface, or add their own search components
- Package Ontologies: Ontologies can now be loaded from a package
- The default ontology has been removed to better accommodate instances without ontologies or custom ontologies
- Workflows: Developers can design workflows to simplify data management operations for their users
- The tile server (TileStache) has been removed in favor of storing vector tiles directly in Postgres
- A grouping card component has been added to cards into a single card
- A map component has been added to manage multiple geometry nodes in a single map interface.
- The map widget has been upgraded with an improved interface
- Custom indexes have been added to allow developers to add their own indexes

### Important:
The method of creating generic relationships is still available in Arches. However, this feature will be deprecated in a future release. Users are strongly encouraged to use the Resource Instance datatype to relate resources.

#### Upgrading Arches


1. Upgrade to Arches 4.4.3
2. Set up a Postgres 12 service with PostGIS 3.0. Ideally this will be on a separate server from the one supporting Arches 4.
3. Carefully follow instructions to upgrade each Arches project database to Postgres 12. https://www.postgresql.org/docs/current/upgrading.html  
4. Install Elasticsearch 7.4
5. Install Python 3.6 or 3.7. If you are running Arches on Ubuntu 18.04 we recommend version 3.6
6. Create a Python 3 virtual environment, activate your new virtual environment and install Arches:

        python -m venv env
        source env/bin/activate
        (env) pip install arches

7. Within your project with your Python 3 virtual environment activated:


        python manage.py es delete_indexes
        python manage.py es setup_indexes
        python manage.py migrate
        python manage.py es index_database


8. (optional) Install a message queue and set up the task manager.

    https://arches.readthedocs.io/en/latest/task-management/



#### Upgrading an Arches project

1.  Make the following changes to your project's package.json file:

    Add:  

         "@mapbox/geojsonhint": "^3.0.0"
         "@mapbox/mapbox-gl-geocoder": "^4.4.0"

    Upgrade:

        "@mapbox/mapbox-gl-draw": "1.1.2",
        "bootstrap": "3.3.7",
        "ckeditor": "^4.6.2",
        "knockout": "3.5.0",
        "mapbox-gl": "^1.0.0",
        "numeral": "^2.0.6",

    Remove:

        "mathjs": "^3.11.4",
        "nvd3": "^1.8.5",

    and finally run:

        `yarn install`

2. Because TileStache has been removed from core arches, any services that were provided by the tile server will need to be provided by another server such as GeoServer.

### Known Issues:
- The Docker install needs to be updated to support the dependency changes.


# Testing Script

Before Version Release, go through this checklist to confirm that Arches is running as intended.

## Index

| Test Subject   |      Chrome     |    Firefox     |  UI                        | Notes                                |
| -------------- | :-------------: | :-------------: | ------------------------- | ------------------------------------ |
| (Test Subject) | (use indicator from list below) |  (use indicator from list below) |     ?     (to confirm that the UI has rendered correctly) or :x: (to confirm that the UI failed to render correctly) | (add ticket #, details on bug, etc.) |


When doing a test pass, consider using these status indicators:
:white_check_mark: = Tested & Approved
:x: = Merge blocking  
:construction: = Non-blocking bugs  
:ok: = Issue has been fixed  
:question: = Open question  

* * *

## Install

Assigned to: Namjun

| Test Subject                                                   | Chrome | Firefox | UI  | Notes |
| -------------------------------------------------------------- | :----: | :-----: | --- | ----- |
| Confirm that upgrading from the previous release is issue free |   :white_check_mark:   |  ?   | ?   | setup_indexes -> migrate -> index_database     |

* * *

## Authentication

Assigned to: Alexei

Ensure that all browsers are compatible with Authentication process.

| Test Subject                                                             | Chrome |  Firefox | UI  | Notes |
| ------------------------------------------------------------------------ | :----: | :-----: |  --- | ----- |
| User can sign themselves up for a new Arches account                     | :white_check_mark: |    ?    | ?   |#5746 #5814|
| User is added to default group (Crowdsource Editor)                      | :white_check_mark: |    ?    | ?   |   -    |
| User can log in with their email address                                 | :white_check_mark: |    ?    | ?   |   -    |
| User can log in with their user_name                                     | :white_check_mark: |    ?    | ?   |   -    |
| User can reset their password                                            | :white_check_mark: |    ?    | ?   |   -   |
| User can edit their profile (First and Last name, email address, etc...) | :white_check_mark: |    ?    | ?   |  -   |
| Admin User can create account with lesser privileges, login as them      |:white_check_mark:|    ?    | ?   | -  |
| Setting permissions for a user or group as No Access removes the user and group from the permissions list under the permissions tab. |:white_check_mark:|    ?    | ?   |  -  |

* * *

## System Settings

Assigned to:

#### Basic Settings

| Test Subject                                                                                                                 | Chrome | Firefox | UI  | Notes |
| ---------------------------------------------------------------------------------------------------------------------------- | :----: | :-----: | --- | ----- |
| Project Name - Updating name updates in index.htm and the page tab                                                          |:white_check_mark:|    ?    | ?   | -     |
| Web Analytics - String value inserts in base.htm at the location of this template variable:{{GOOGLE_ANALYTICS_TRACKING_ID}} |:white_check_mark:|    ?    | ?   | -     |

#### Map Settings

Assigned to: Galen

| Test Subject                                                                                                                                                                                    | Chrome | Firefox | UI  | Notes |
| ----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- | :----: | :-----: | --- | ----- |
| Mapbox API Key - Key saves and API calls are successful   |:white_check_mark:|   ?    | ?   | -     |
| Hex Grid Precision - Saves properly, but errors if precision is too high (\`Exception detail: TransportError(400, u'parsing_exception', u'[geohash_grid] failed to parse field [precision]')``) |:white_check_mark:|   ?    | ?   | -     |
| Hex Cell Size - Changes reflected in Search results       |:white_check_mark:|   ?    | ?   | -     |
| Default Zoom - Changes reflected in Card Config Manager   |:white_check_mark:|   ?    | ?   | -     |
| Min Zoom - Changes reflected in Card Config Manager       |:white_check_mark:|   ?    | ?   | -     |
| Max Zoom - Changes reflected in Card Config Manager       |:white_check_mark:|   ?    | ?   | -     |
| Project Extent - Changes reflected in Card Config Manager |:white_check_mark:|   ?    | ?   | -     |

#### Search Settings

Assigned to: Galen

Basic Search Settings

| Test Subject                                                   | Chrome | Firefox  | UI  | Notes |
| -------------------------------------------------------------- | :----: | :-----:  | --- | ----- |
| Searches per page updates properly in Search                   |:white_check_mark:|   ?    |  ?   | -     |
| Number of search suggestions is reflected in search term input |:white_check_mark:|   ?    |  ?   | -     |

<!-- Temporal Search Settings (not in use)

| Test Subject                                                                                       | Chrome | Firefox | UI  | Notes |
| -------------------------------------------------------------------------------------------------- | :----: | :-----: | --- | ----- |
| Changes in time wheel color ramp are reflected in time wheel change time wheel colors (not in use) |    ?    |    -    | -   | -     |
| Changes in time wheel config are reflected in time wheel (not in use)                              |    ?    |    -    | -   | -     | -->

Saved Searches

| Test Subject                                                                                                       | Chrome | Firefox | UI  | Notes |
| ------------------------------------------------------------------------------------------------------------------ | :----: | :-----: | --- | ----- |
| A new search saves with a name, search url, description, and image and displays properly in the saved search page. |:white_check_mark:|   ?    | ?   | -     |
| Users can delete a saved search                                                                                    |:white_check_mark:|   ?    | ?   | - |

* * *

## Map Widget

Assigned to: Galen

Test in the Card Configuration Manager.

| Test Subject                                                                                                                                            | Chrome | Firefox | UI  | Notes |
| ------------------------------------------------------------------------------------------------------------------------------------------------------- | :----: | :-----: | --- | ----- |
| Point line and poly geoms can be created, edited, and deleted  |:white_check_mark:|    ?    | ?   |   -   |
| XY widget is working properly                                  |:white_check_mark:|    ?    | ?   | -     |
| Valid geojson entered in the geojson input adds features to the map and pans to those features. If geojson is invalid user has a chance to update data. |:white_check_mark:|    ?    | ?   | -     |
| Overlays support custom popups                                                                                                         |:construction:|    ?    | ?   |Not supported yet|


* * *

## Map Layer Manager

Assigned to: Rob

#### Resource Layers

Assigned to: Rob

| Test Subject                                                                                                                         | Chrome | Firefox | UI  | Notes |
| ------------------------------------------------------------------------------------------------------------------------------------ | :----: | :-----: | --- | ----- |
| Settings - changes to the name and icon of a layer are reflected in the map widget overlay list and overlay library  |    :white_check_mark:    |    ?    | ?   | -     |
| Deactivating/Activating a resource layer hides/shows the layer in the map widget overlay list and overlay library    |    :white_check_mark:   |    ?    | ?   | -  |
| Style Settings - changes to the layer style are displayed in the layer                                               |    :white_check_mark:   |    ?    | ?   | -     |
| Style Settings Advanced - changes to the layer style are displayed in the layer                                      |    :white_check_mark:   |    ?    | ?   | -     |


#### Clustering (Resource Layers)

Assigned to: Rob

| Test Subject                                                                               | Chrome | Firefox | UI  | Notes |
| ------------------------------------------------------------------------------------------ | :----: | :-----: | --- | ----- |
| Increasing cluster distance causes features to cluster at increased distances between them |   :white_check_mark:   |    ?    | ?   | -     |
| Increasing cluster max zoom causes clusters to be formed at higher zoom levels             |   :white_check_mark:   |    ?    | ?   | -     |
| Decreasing min points to 2 points causes clusters to form with only 2 points               |   :white_check_mark:   |    ?    | ?   | -     |


#### Basemaps

Assigned to: Rob

| Test Subject                                                                                    | Chrome | Firefox | UI  | Notes |
| ----------------------------------------------------------------------------------------------- | :----: | :-----: | --- | ----- |
| Changing the default search basemap in the basemap settings is reflected on the search page     |    :white_check_mark:   |    ?    | ?   | -     |
| Settings - changes to the name and icon of a layer are reflected in the map widget basemap list |    :white_check_mark:   |    ?    | ?   | -     |
| User can delete a basemap and it no longer appears in the map widget's list of basemaps         |    :white_check_mark:   |    ?    | ?   | -     |

#### Overlays

Assigned to: Rob

| Test Subject                                                                                                        | Chrome | Firefox | UI  | Notes |
| ------------------------------------------------------------------------------------------------------------------- | :----: | :-----: | --- | ----- |
| Settings - changes to the name and icon of a layer are reflected in the map widget overlay list and overlay library |:white_check_mark:|    ?    | ?   | -     |
| User can delete an overlay and it no longer appears in the map widget overlay library                               |:white_check_mark:|    ?    | ?   | -     |

* * *

## Import/Export

Assigned to: Galen

| Test Subject               | Chrome | Firefox | UI  | Notes |
| -------------------------- | :----: | :-----: | --- | ----- |
| Create_mapping_file        |:white_check_mark:|    ?    | ?   | -     |
| Import business data (cli) |:white_check_mark:|    ?    | ?   | -    |
| Export business data (cli) |:white_check_mark:|    ?    | ?   | -     |
| Load package (cli)         |:white_check_mark:|    ?    | ?   | -     |
| Create package (cli)       |:white_check_mark:|    ?    | ?   | -     |

* * *

## Resource Instance Management

Assigned to: Namjun

#### Data Types

Confirm that the user is able to edit the following data types. Use the Test model to quickly test all ten data types.
Note (GeoJson is covered by map widget testing in a different section)

| Test Subject           | Chrome | Firefox |  UI  | Notes |
| ---------------------- | :----: | :-----: |  --- | ----- |
| String                 |:white_check_mark: |    ?    |  ?   | -     |
| Concepts               |:white_check_mark: |    ?    |  ?   | -     |
| Domains                |:white_check_mark: |    ?    |  ?   | -   |
| Images                 |:white_check_mark: |    ?    |  ?   | -     |
| Dates                  |:white_check_mark: |    ?    |  ?   | -     |
| Number                 |:white_check_mark: |    ?    |  ?   | -     |
| Boolean                |:white_check_mark: |    ?    |  ?   | -     |
| Resource instance type |:white_check_mark: |    ?    |  ?   | -     |
| Resource instance-list |:white_check_mark: |    ?    |  ?   | -     |
| Node data type         |:white_check_mark: |    ?    |  ?   | -     |
| File-list data type    |:white_check_mark: |    ?    |  ?   | -     |
| edtf                   |:white_check_mark: |    ?    |  ?   | -     |

#### Resource Descriptors

Assigned to: Alexei

Updating a resource descriptor should be reflected in the following subjects.

| Test Subject                                                                                        | Chrome | Firefox | UI  | Notes |
| --------------------------------------------------------------------------------------------------- | :----: | :-----: | --- | ----- |
| Search results                                                                                      | :white_check_mark: |     ?      | ?   |-      |
| Form headings                                                                                       | :white_check_mark: |     ?      | ?   | -     |
| Report headings                                                                                     | :white_check_mark: |     ?      | ?   | -     |
| Map popups                                                                                          | :white_check_mark: |     ?      | ?   | -     |
| Related resource d3 graph and listings                                                              | :white_check_mark: |     ?      | ?   | -     |

* * *

#### Provisional Edit Management

Assigned to: Galen

| Test Subject                                           | Chrome | Firefox | UI  | Notes |
| ------------------------------------------------------ | :----: | :-----: | --- | ----- |
| Provisional users see indication in a widget that their tile edits were submitted                   |:white_check_mark:|    ?    | ?   | -     |
| Resource reviewers are able to identify provisional tiles and can approve/discard provisional edits |:white_check_mark:|    ?    | ?   | -     |

* * *

## Related Resources

Assigned to: Galen

#### Resource Editor

| Test Subject                                           | Chrome | Firefox | UI  | Notes |
| ------------------------------------------------------ | :----: | :-----: | --- | ----- |
| User can add a related resource                        |:white_check_mark:|    ?    | ?   | -     |
| User can delete a related resource                     |:white_check_mark:|    ?    | ?   | -     |
| User can change the properties of related resources    |:white_check_mark:|    ?    | ?   | -     |
| User can switch between table and force directed graph |:white_check_mark:|    ?    | ?   | -     |
| User can page through related resources in table       |:white_check_mark:|    ?    | ?   | -     |

#### Resource Search

| Test Subject                                                                                                                           | Chrome | Firefox | UI  | Notes |
| -------------------------------------------------------------------------------------------------------------------------------------- | :----: | :-----: | --- | ----- |
| Hovering over a link in the force directed graph opens a panel with source and target node info and list each unique relationship type |:white_check_mark:|   ?    | ?   | -     |
| Hovering over a node highlights the adjacent links and the corresponding entry in the node list                                        |:white_check_mark:|   ?    | ?   | -     |
| Hovering over a node list entry highlights the corresponding node and its adjacent links                                               |:white_check_mark:|   ?    | ?   | -     |
| User can switch between table and force directed graph                                                                                 |:white_check_mark:|   ?    | ?   | -     |
| Entering text in the search field filters the list of list entries                                                                     |:white_check_mark:|   ?    | ?   | -     |

* * *

## Search

Assigned to: Galen

| Test Subject                                                                                                                                                                         | Chrome | Firefox | UI  | Notes |
| ------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------ | :----: | :-----: | --- | ----- |
| Free text search                                                                                                                                                                     | :white_check_mark: |  ?  |   ?   | -     |
| Concept search                                                                                                                                                                       | :white_check_mark: |  ?  |   ?   | -     |
| Map filter search                                                                                                                                                                    | :white_check_mark: |     ?     |   ?   | -     |
| Time range based search                                                                                                                                                              | :white_check_mark: |     ?     |   ?   | -     |
| Time wheel search                                                                                                                                                                    | :white_check_mark: |     ?     |   ?   | -     |
| Advanced search                                                                                                                                                                      | :white_check_mark: |  ?  |   ?   | -     |
| Related resource table search                                                                                                                                                        | :white_check_mark: |    ?    | ?   |Table filter is not available|
| Related resource graph search                                                                                                                                                        | :white_check_mark: |  ?     |   ?   | -     |
| Resource type search                                                                                                                                                                 | :white_check_mark: |  ?  |  ?   |  -     |
| Edit status search (provisional, authoritative, or both). Confirm that only resource reviewers are able to see provisional tile data                                                 | :white_check_mark: |  ?  | ?   | -     |
| Map should not zoom to points that a user is not permitted to read, nor should the search aggregation layer (e.g. hexbin or heatmap) indicate that a restricted resource is present. | :white_check_mark: |   ?     |  ?   | -     |

Advanced Search

| Test Subject                                                   | Chrome | Firefox  | UI  | Notes |
| -------------------------------------------------------------- | :----: | :-----:  | --- | ----- |
| "Like" and "Not Like" return expected results                  | :white_check_mark: |   ?    |  ?   | -     |
| "Equals" and "Not" return expected results                     | :white_check_mark: |   ?    |  ?   | -     |
| =,<=,>=,<,> for number-type data return expected results       | :white_check_mark: |   ?    |  ?   | -     |
| Removing or Adding filters updates results as expected         | :white_check_mark: |   ?    |  ?   | -     |
| Multiple filters return expected results                       | :white_check_mark: |   ?    |  ?   | -     |


Search Export

| Test Subject                                                   | Chrome | Firefox | UI | Notes |
| -------------------------------------------------------------- | :----: | :-----: | --- | ----- |
| Search Export works for nodes of *all* datatypes               | :white_check_mark: |   ?     |  ? |  ?    |
| Search Export downloads immediately if under limit threshold   | :white_check_mark: |   ?     |  ? |  ?    |
| Search Export creates notification if over limit threshold     | :white_check_mark: |   ?     |  ? |  ?    |
| Export disabled if celery not running and over limit threshold | :white_check_mark: |   ?     |  ? |  ?    |

* * *

## Graph Design

Assigned to: Galen

### Arches Designer

| Test Subject     | Chrome | Firefox | UI  | Notes |
| ---------------- | :----: | :-----: | --- | ----- |
| Import graph     |:white_check_mark:|    ?    | ?   | -     |
| Export graph     |:white_check_mark:|    ?    | ?   | -     |
| Clone graph      |:white_check_mark:|    ?    | ?   | -     |
| Delete graph     |:white_check_mark:|    ?    | ?   | -     |
| Create branch    |:white_check_mark:|    ?    | ?   | -     |
| Create graph     |:white_check_mark:|    ?    | ?   | -     |
| Delete Instances |:white_check_mark:|    ?    | ?   | -     |

### Graph Designer

| Test Subject             | Chrome | Firefox | UI  | Notes |
| ------------------------ | :----: | :-----: | --- | ----- |
| Import graph             |:white_check_mark:|    ?    | ?   |(?)Popup blocker will block the new windows for some of these functions.|
| Export graph             |:white_check_mark:|    ?    | ?   | -     |
| Clone graph              |:white_check_mark:|    ?    | ?   | -     |
| Delete graph             |:white_check_mark:|    ?    | ?   | -     |
| Create branch            |:white_check_mark:|    ?    | ?   | -     |
| Create graph             |:white_check_mark:|    ?    | ?   | -     |
| Delete Instances         |:white_check_mark:|    ?    | ?   | -     |
| Add/Edit cards           |:white_check_mark:|    ?    | ?   | -     |
| Reorder widgets  in card |:white_check_mark:|    ?    | ?   | -     |

* * *

## Permissions Management

Assigned to: Galen

| Test Subject                                                                                                                                            | Chrome | Firefox | UI  | Notes |
| ------------------------------------------------------------------------------------------------------------------------------------------------------- | :----: | :-----: | --- | ----- |
| Confirm removing `read` permissions removes that section from the report                                                                                |:white_check_mark:|    ?    | ?   | -     |
| Confirm removing `read` permissions removes that section from the form                                                                                  |:white_check_mark:|    ?    | ?   | -     |
| Confirm removing `read` permissions removes that section from the adv. search                                                                           |:white_check_mark:|    ?    | ?   | -     |
| Confirm removing `read` permissions for a spatial nodegroup removes that resource type from map based search results                                    |:white_check_mark:|    ?    | ?   | -     |
| Confirm removing `read` permissions for a spatial nodegroup removes that resource type from the overlays section of the map settings                    |:white_check_mark:|    ?    | ?   | -     |
| Confirm removing `read` permissions for a spatial nodegroup removes the map from the Map Report                                                         |:white_check_mark:|    ?    | ?   | -     |
| Confirm removing `read` permissions for a date based nodegroup removes the related entries from the type dropdown in the time filter of the search page |:white_check_mark:|    ?    | ?   | -     |
| Confirm removing `read` permissions for a date based nodegroup reduces the wheel count appropriately                                                    |:white_check_mark:|    ?    | ?   | -     |
| Confirm removing `write` permissions but still having read permissions disallows saving that section of the form                                        |:white_check_mark:|    ?    | ?   | -     |

* * *

## Reports

Assigned to: Galen

#### Headers Rendering

| Test Subject                                                            | Chrome | Firefox | UI  | Notes |
| ----------------------------------------------------------------------- | :----: | :-----: | --- | ----- |
| Confirm that report templates with map header gets rendered correctly   |:white_check_mark:|    ?    | ?   | -     |
| Confirm that report templates with image header gets rendered correctly |:white_check_mark:|    ?    | ?   | -     |
| Confirm that report templates with no header gets rendered correctly    |:white_check_mark:|    ?    | ?   | -     |

#### Data Rendering

| Test Subject           | Chrome | Firefox | UI  | Notes |
| ---------------------- | :----: | :-----: | --- | ----- |
| String                 |:white_check_mark:|    ?    | ?   | -     |
| Concepts               |:white_check_mark:|    ?    | ?   | -     |
| Domains                |:white_check_mark:|    ?    | ?   | -     |
| Images                 |:white_check_mark:|    ?    | ?   | -     |
| Dates                  |:white_check_mark:|    ?    | ?   | -     |
| Number                 |:white_check_mark:|    ?    | ?   | -     |
| Boolean                |:white_check_mark:|    ?    | ?   | -     |
| Resource instance type |:white_check_mark:|    ?    | ?   | -     |
| Node data type         |:white_check_mark:|    ?    | ?   | -     |
| File-list type         |:white_check_mark:|    ?    | ?   | -     |

* * *

## RDM

Assigned to: Namjun

#### Thesauri

| Test Subject       | Chrome | Firefox | UI  | Notes |
| ------------------ | :----: | :-----: | --- | ----- |
| Add scheme         |:white_check_mark:|    ?    | ?   |Dialogue contents do not update right away|
| Delete scheme      |:white_check_mark:|    ?    | ?   | -     |
| Import scheme      |:white_check_mark:|    ?    | ?   |Does not import images|
| Export scheme      |:white_check_mark:|    ?    | ?   |Does not import images|
| Add top concept    |:white_check_mark:|    ?    | ?   | -     |
| Import from SPARQL |:white_check_mark:|    ?    | ?   |The tree on the left is not refreshed on import |
| Manage parents     |:white_check_mark:|    ?    | ?   |When polyhierachy is set, the selection not deactivated |
| Make collection    |:white_check_mark:|    ?    | ?   |If a user creates two collections with the same name they will not be able to delete either of them|
| Add label          |:white_check_mark:|    ?    | ?   | -     |
| Add Note           |:white_check_mark:|    ?    | ?   | -     |
| Add image          |:white_check_mark:|    ?    | ?   | -     |

#### Collections

| Test Subject                           | Chrome | Firefox | UI  | Notes |
| -------------------------------------- | :----: | :-----: | --- | ----- |
| Add collection                         |:white_check_mark:|    ?    | ?   | -     |
| Delete collection                      |:white_check_mark:|    ?    | ?   | -     |
| Export all collections                 |:white_check_mark:|    ?    | ?   |this action redirects to this url with inline xml file:/concepts/export/collections|
| Add dropdown entry                     |:white_check_mark:|    ?    | ?   | -     |
| Add sort order and confirm in dropdown |:white_check_mark:|    ?    | ?   | -     |

* * *


## Arches Collector Manager

| Test Subject                                                                         | Chrome | Firefox | UI  | Notes |
| -------------------------------------------------------------------------------------| :----: | :-----: | --- | ----- |
| Create new Project                                                                   |:white_check_mark:|    ?    | ?   | -     |
| Save project upon selecting resource type and data entry card(s)                     |:white_check_mark:|    ?    | ?   |  -  |



* * *
