Arches 7.5.0 release notes
------------------------

### Major enhancements
- TBD

### Additional highlights


### Dependency changes
```
Python:
    Upgraded:
        Django 3.2.20 > 4.2.4
        django-celery-results 2.4.0 > 2.5.1
        django-compressor 3.1 > 4.4
        django-cors-headers 3.1.1 > 4.2.0
        django-guardian 2.3.0 > 2.4.0
        django-recaptcha 2.0.6 > 3.0.0
        django-oauth-toolkit 1.2.0 > 1.7.0
        django-webpack-loader 1.5.0 > 2.0.1

    Added:

    Removed:
        (dev dependencies):
            webtest
            django-webtest
            django-nose

JavaScript:
    Upgraded:

    Added:
```

### Breaking changes
None

### Upgrading Arches

1. You must be upgraded to at least version 7.4.0 before proceeding. If you are on an earlier version, please refer to the upgrade process in the [Version 7.2.0 release notes](https://github.com/archesproject/arches/blob/dev/7.4.x/releases/7.4.0.md)

2. Be sure to backup your database before proceeding.

3. Upgrade to Arches 7.5.0
    ```
    pip install --upgrade arches==7.5.0
    ```

4. Uninstall mooted dev dependencies:
    ```
    pip uninstall webtest
    pip uninstall django-webtest
    pip uninstall django-nose
    ```

### Upgrading an Arches project

1. In urls.py, replace each `django.conf.urls.url()` call with `django.urls.re_path()` if it uses a regular expression, or `django.urls.path()` if it does not.

2. Replace any calls to `django.utils.translation.ugettext()` with `django.utils.translation.gettext()`.

3. In settings.py (or settings_local.py, etc.), remove `USE_L10N`. If present, replace `DEFAULT_FILE_STORAGE` with `STORAGES["default"]["BACKEND"]` and/or `STATICFILES_STORAGE` with `STORAGES["staticfiles"]["BACKEND"]`. (An example configuration can be found in the [Django documentation](https://docs.djangoproject.com/en/4.2/ref/settings/#storages).)

4. Within your project, with your Python 3 virtual environment activated:
    ```
    python manage.py makemigrations  # commit the result
    python manage.py migrate
    ```

2. Reindex your database:
    ```
    python manage.py es reindex_database
    ```

3. If you have made customizations to files in your webpack directory, backup that directory as those files will be overwritten in the following steps. Read [this](https://github.com/archesproject/arches/blob/9304-cbyrd-arches-installed-packages/arches/webpack/README.md) for more information.

4. If you have javascript dependencies listed in `webpack/webpack-node-modules-aliases.js`, move them to your package.json file and update the paths. For example, if you have dependencies in `webpack/webpack-node-modules-aliases.js` like this:
    ```
    module.exports = {
        PROJECT_NODE_MODULES_ALIASES: JSON.stringify({
            "plotly.js-dist": "Path.resolve(__dirname, `${APP_ROOT}/media/node_modules/plotly.js-dist`)",
            "Plotly": "Path.resolve(__dirname, `${APP_ROOT}/media/node_modules/plotly.js-dist`)"
        }),
    };
    ```
    They must be moved to an object called `nodeModulesPaths` in your project's package.json like this:
    ```
    "nodeModulesPaths": {
        "plotly.js-dist": "node_modules/plotly.js-dist",
        "Plotly": "node_modules/plotly.js-dist",
    },
    ```

5. Run `python manage.py updateproject`

6. Update your settings.py file:
    1. Add the ARCHES_APPLICATIONS SETTING:

        ```ARCHES_APPLICATIONS = ()``` 

    2. Replace:
        ```
        STATICFILES_DIRS = (
            os.path.join(APP_ROOT, "media", "build"),
            os.path.join(APP_ROOT, "media"),
        ) + STATICFILES_DIRS
        ```
        with:
        ```
        STATICFILES_DIRS =  build_staticfiles_dirs(
            root_dir=ROOT_DIR,
            app_root=APP_ROOT,
            arches_applications=ARCHES_APPLICATIONS,
        )
        ```

    3. Replace:
        ```
        TEMPLATES[0]['DIRS'].append(os.path.join(APP_ROOT, 'functions', 'templates'))
        TEMPLATES[0]['DIRS'].append(os.path.join(APP_ROOT, 'widgets', 'templates'))
        TEMPLATES[0]['DIRS'].insert(0, os.path.join(APP_ROOT, 'templates'))
        ```
        with:
        ```
        TEMPLATES = build_templates_config(
            root_dir=ROOT_DIR,
            debug=DEBUG,
            app_root=APP_ROOT,
            arches_applications=ARCHES_APPLICATIONS,
        )
        ```

    4. Replace:
        ```
        if __name__ == "__main__":
            print(
                json.dumps(
                    {
                        "ARCHES_NAMESPACE_FOR_DATA_EXPORT": ARCHES_NAMESPACE_FOR_DATA_EXPORT,
                        "STATIC_URL": STATIC_URL,
                        "ROOT_DIR": ROOT_DIR,
                        "APP_ROOT": APP_ROOT,
                        "WEBPACK_DEVELOPMENT_SERVER_PORT": WEBPACK_DEVELOPMENT_SERVER_PORT,
                    }
                )
            )
            sys.stdout.flush()
        ```
        with:
        ```
        if __name__ == "__main__":
            transmit_webpack_django_config(
                root_dir=ROOT_DIR,
                app_root=APP_ROOT,
                arches_applications=ARCHES_APPLICATIONS,
                public_server_address=PUBLIC_SERVER_ADDRESS,
                static_url=STATIC_URL,
                webpack_development_server_port=WEBPACK_DEVELOPMENT_SERVER_PORT,
            )
        ```

7. If your project is running on a port other than 8000, set the PUBLIC_SERVER_ADDRESS to that location, eg:
   
    ```PUBLIC_SERVER_ADDRESS = 'http://localhost:8009'```

    NOTE: If you have overwritten `ARCHES_NAMESPACE_FOR_DATA_EXPORT` in your project's `settings.py` file, `PUBLIC_SERVER_ADDRESS` should be set to that value.


8. Update your project's JavaScript dependencies:

    1.  In the project's `package.json` file from `stable/7.4.0` to `stable/7.5.0`:
        ```    
        {
            "dependencies": {
                "arches": "archesproject/arches#stable/7.5.0",
            },
            "devDependencies": {
                "arches-dev-dependencies": "archesproject/arches-dev-dependencies#stable/7.5.0"
            }
        }
        ```

    2.  Ensure `nodeModulesPaths` has been added to your `package.json` file:
        ```    
        {
            "dependencies": {
                "arches": "archesproject/arches#stable/7.5.0",
            },
            "devDependencies": {
                "arches-dev-dependencies": "archesproject/arches-dev-dependencies#stable/7.5.0"
            },
            "nodeModulesPaths": {}
        }
        ```

    3. Remove your `media/node_modules` directory and `yarn.lock` file

    4. In your terminal navigate to the directory with your project's package.json file. Then run:

        yarn install

        
9. Start your application server in a separate terminal if it's not already running.

10. In the same terminal window where you ran `yarn` ( on the same level as `package.json` ), run `yarn start` or `yarn build_development`. This will generate your `media/build` directory.
    - If running your project in development:
     -  `yarn start` will build the frontend of the application and then start a webpack development server
      - `yarn build_development` will build a development bundle for the frontend assests of the application -- this should complete in less than 2 minutes
    - If running your project in production:
      - `yarn build_production` This builds a production bundle. **takes up to 2hrs depending on resources**
      - Alternatively you can `cd ..` up a directory and run `python manage.py build_production`. This will create a production bundle of frontend assessts and also call `collectstatic`.

11. If you are running Arches on Apache, be sure to run:

    ```
    collectstatic
    ```
    and restart your server
    ```
    sudo service apache2 reload
    ```

